@@ -26,5 +26,8 @@
 #' coov = get_cocove(coom)
 #' coov
 get_cocove = function(x, ordered = TRUE, normalization = "none"){
+  if (!ordered){
+    warning("`ordered = FALSE` may return incorrect results for `cocove` when the input matrix is not a square matrix", call. = FALSE)
+  }
   rcpp_get_cocove(x, ordered, normalization)
 }
